==> ShapeView-6.2-sources.jar: com/hjq/shape/styleable/ShapeRadioButtonStyleable.java <==
package com.hjq.shape.styleable;

import com.hjq.shape.R;

/**
 *    author : Android 轮子哥
 *    github : https://github.com/getActivity/ShapeView
 *    time   : 2021/08/28
 *    desc   : RadioButton 的 Shape 属性值
 */
public final class ShapeRadioButtonStyleable implements IShapeDrawableStyleable,
        ITextColorStyleable, ICompoundButtonStyleable {

    /**
     * {@link IShapeDrawableStyleable}
     */

    @Override
    public int getShapeTypeStyleable() {
        return R.styleable.ShapeRadioButton_shape;
    }

    @Override
    public int getShapeWidthStyleable() {
        return R.styleable.ShapeRadioButton_shape_width;
    }

    @Override
    public int getShapeHeightStyleable() {
        return R.styleable.ShapeRadioButton_shape_height;
    }

    @Override
    public int getSolidColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_solidColor;
    }

    @Override
    public int getSolidPressedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_solidPressedColor;
    }

    @Override
    public int getSolidCheckedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_solidCheckedColor;
    }

    @Override
    public int getSolidDisabledColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_solidDisabledColor;
    }

    @Override
    public int getSolidFocusedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_solidFocusedColor;
    }

    @Override
    public int getSolidSelectedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_solidSelectedColor;
    }

    @Override
    public int getRadiusStyleable() {
        return R.styleable.ShapeRadioButton_shape_radius;
    }

    @Override
    public int getTopLeftRadiusStyleable() {
        return R.styleable.ShapeRadioButton_shape_topLeftRadius;
    }

    @Override
    public int getTopRightRadiusStyleable() {
        return R.styleable.ShapeRadioButton_shape_topRightRadius;
    }

    @Override
    public int getBottomLeftRadiusStyleable() {
        return R.styleable.ShapeRadioButton_shape_bottomLeftRadius;
    }

    @Override
    public int getBottomRightRadiusStyleable() {
        return R.styleable.ShapeRadioButton_shape_bottomRightRadius;
    }

    @Override
    public int getStartColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_startColor;
    }

    @Override
    public int getCenterColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_centerColor;
    }

    @Override
    public int getEndColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_endColor;
    }

    @Override
    public int getUseLevelStyleable() {
        return R.styleable.ShapeRadioButton_shape_useLevel;
    }

    @Override
    public int getAngleStyleable() {
        return R.styleable.ShapeRadioButton_shape_angle;
    }

    @Override
    public int getGradientTypeStyleable() {
        return R.styleable.ShapeRadioButton_shape_gradientType;
    }

    @Override
    public int getCenterXStyleable() {
        return R.styleable.ShapeRadioButton_shape_centerX;
    }

    @Override
    public int getCenterYStyleable() {
        return R.styleable.ShapeRadioButton_shape_centerY;
    }

    @Override
    public int getGradientRadiusStyleable() {
        return R.styleable.ShapeRadioButton_shape_gradientRadius;
    }

    @Override
    public int getStrokeColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokeColor;
    }

    @Override
    public int getStrokePressedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokePressedColor;
    }

    @Override
    public int getStrokeCheckedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokeCheckedColor;
    }

    @Override
    public int getStrokeDisabledColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokeDisabledColor;
    }

    @Override
    public int getStrokeFocusedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokeFocusedColor;
    }

    @Override
    public int getStrokeSelectedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokeSelectedColor;
    }

    @Override
    public int getStrokeWidthStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokeWidth;
    }

    @Override
    public int getDashWidthStyleable() {
        return R.styleable.ShapeRadioButton_shape_dashWidth;
    }

    @Override
    public int getDashGapStyleable() {
        return R.styleable.ShapeRadioButton_shape_dashGap;
    }

    @Override
    public int getInnerRadiusStyleable() {
        return R.styleable.ShapeRadioButton_shape_innerRadius;
    }

    @Override
    public int getInnerRadiusRatioStyleable() {
        return R.styleable.ShapeRadioButton_shape_innerRadiusRatio;
    }

    @Override
    public int getThicknessStyleable() {
        return R.styleable.ShapeRadioButton_shape_thickness;
    }

    @Override
    public int getThicknessRatioStyleable() {
        return R.styleable.ShapeRadioButton_shape_thicknessRatio;
    }

    @Override
    public int getShadowSizeStyleable() {
        return R.styleable.ShapeRadioButton_shape_shadowSize;
    }

    @Override
    public int getShadowColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_shadowColor;
    }

    @Override
    public int getShadowOffsetXStyleable() {
        return R.styleable.ShapeRadioButton_shape_shadowOffsetX;
    }

    @Override
    public int getShadowOffsetYStyleable() {
        return R.styleable.ShapeRadioButton_shape_shadowOffsetY;
    }

    /**
     * {@link ITextColorStyleable}
     */

    @Override
    public int getTextColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textColor;
    }

    @Override
    public int getTextPressedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textPressedColor;
    }

    @Override
    public int getTextCheckedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textCheckedColor;
    }

    @Override
    public int getTextDisabledColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textDisabledColor;
    }

    @Override
    public int getTextFocusedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textFocusedColor;
    }

    @Override
    public int getTextSelectedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textSelectedColor;
    }

    @Override
    public int getTextStartColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textStartColor;
    }

    @Override
    public int getTextCenterColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textCenterColor;
    }

    @Override
    public int getTextEndColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textEndColor;
    }

    @Override
    public int getTextGradientOrientationStyleable() {
        return R.styleable.ShapeRadioButton_shape_textGradientOrientation;
    }
    /**
     * {@link ICompoundButtonStyleable}
     */

    @Override
    public int getButtonDrawableStyleable() {
        return R.styleable.ShapeRadioButton_shape_buttonDrawable;
    }

    @Override
    public int getButtonPressedDrawableStyleable() {
        return R.styleable.ShapeRadioButton_shape_buttonPressedDrawable;
    }

    @Override
    public int getButtonCheckedDrawableStyleable() {
        return R.styleable.ShapeRadioButton_shape_buttonCheckedDrawable;
    }

    @Override
    public int getButtonDisabledDrawableStyleable() {
        return R.styleable.ShapeRadioButton_shape_buttonDisabledDrawable;
    }

    @Override
    public int getButtonFocusedDrawableStyleable() {
        return R.styleable.ShapeRadioButton_shape_buttonFocusedDrawable;
    }

    @Override
    public int getButtonSelectedDrawableStyleable() {
        return R.styleable.ShapeRadioButton_shape_buttonSelectedDrawable;
    }
}

==> ShapeView-8.0-sources.jar: com/hjq/shape/styleable/ShapeRadioButtonStyleable.java <==
package com.hjq.shape.styleable;

import com.hjq.shape.R;

/**
 *    author : Android 轮子哥
 *    github : https://github.com/getActivity/ShapeView
 *    time   : 2021/08/28
 *    desc   : RadioButton 的 Shape 属性值
 */
public final class ShapeRadioButtonStyleable implements IShapeDrawableStyleable,
        ITextColorStyleable, ICompoundButtonStyleable {

    /**
     * {@link IShapeDrawableStyleable}
     */

    @Override
    public int getShapeTypeStyleable() {
        return R.styleable.ShapeRadioButton_shape;
    }

    @Override
    public int getShapeWidthStyleable() {
        return R.styleable.ShapeRadioButton_shape_width;
    }

    @Override
    public int getShapeHeightStyleable() {
        return R.styleable.ShapeRadioButton_shape_height;
    }

    @Override
    public int getSolidColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_solidColor;
    }

    @Override
    public int getSolidPressedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_solidPressedColor;
    }

    @Override
    public int getSolidCheckedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_solidCheckedColor;
    }

    @Override
    public int getSolidDisabledColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_solidDisabledColor;
    }

    @Override
    public int getSolidFocusedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_solidFocusedColor;
    }

    @Override
    public int getSolidSelectedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_solidSelectedColor;
    }

    @Override
    public int getRadiusStyleable() {
        return R.styleable.ShapeRadioButton_shape_radius;
    }

    @Override
    public int getTopLeftRadiusStyleable() {
        return R.styleable.ShapeRadioButton_shape_topLeftRadius;
    }

    @Override
    public int getTopRightRadiusStyleable() {
        return R.styleable.ShapeRadioButton_shape_topRightRadius;
    }

    @Override
    public int getBottomLeftRadiusStyleable() {
        return R.styleable.ShapeRadioButton_shape_bottomLeftRadius;
    }

    @Override
    public int getBottomRightRadiusStyleable() {
        return R.styleable.ShapeRadioButton_shape_bottomRightRadius;
    }

    @Override
    public int getSolidStartColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_startColor;
    }

    @Override
    public int getSolidCenterColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_centerColor;
    }

    @Override
    public int getSolidEndColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_endColor;
    }

    @Override
    public int getStrokeStartColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokeStartColor;
    }

    @Override
    public int getStrokeCenterColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokeCenterColor;
    }

    @Override
    public int getStrokeEndColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokeEndColor;
    }

    @Override
    public int getUseLevelStyleable() {
        return R.styleable.ShapeRadioButton_shape_useLevel;
    }

    @Override
    public int getAngleStyleable() {
        return R.styleable.ShapeRadioButton_shape_angle;
    }

    @Override
    public int getGradientTypeStyleable() {
        return R.styleable.ShapeRadioButton_shape_gradientType;
    }

    @Override
    public int getCenterXStyleable() {
        return R.styleable.ShapeRadioButton_shape_centerX;
    }

    @Override
    public int getCenterYStyleable() {
        return R.styleable.ShapeRadioButton_shape_centerY;
    }

    @Override
    public int getGradientRadiusStyleable() {
        return R.styleable.ShapeRadioButton_shape_gradientRadius;
    }

    @Override
    public int getStrokeColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokeColor;
    }

    @Override
    public int getStrokePressedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokePressedColor;
    }

    @Override
    public int getStrokeCheckedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokeCheckedColor;
    }

    @Override
    public int getStrokeDisabledColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokeDisabledColor;
    }

    @Override
    public int getStrokeFocusedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokeFocusedColor;
    }

    @Override
    public int getStrokeSelectedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokeSelectedColor;
    }

    @Override
    public int getStrokeWidthStyleable() {
        return R.styleable.ShapeRadioButton_shape_strokeWidth;
    }

    @Override
    public int getDashWidthStyleable() {
        return R.styleable.ShapeRadioButton_shape_dashWidth;
    }

    @Override
    public int getDashGapStyleable() {
        return R.styleable.ShapeRadioButton_shape_dashGap;
    }

    @Override
    public int getInnerRadiusStyleable() {
        return R.styleable.ShapeRadioButton_shape_innerRadius;
    }

    @Override
    public int getInnerRadiusRatioStyleable() {
        return R.styleable.ShapeRadioButton_shape_innerRadiusRatio;
    }

    @Override
    public int getThicknessStyleable() {
        return R.styleable.ShapeRadioButton_shape_thickness;
    }

    @Override
    public int getThicknessRatioStyleable() {
        return R.styleable.ShapeRadioButton_shape_thicknessRatio;
    }

    @Override
    public int getShadowSizeStyleable() {
        return R.styleable.ShapeRadioButton_shape_shadowSize;
    }

    @Override
    public int getShadowColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_shadowColor;
    }

    @Override
    public int getShadowOffsetXStyleable() {
        return R.styleable.ShapeRadioButton_shape_shadowOffsetX;
    }

    @Override
    public int getShadowOffsetYStyleable() {
        return R.styleable.ShapeRadioButton_shape_shadowOffsetY;
    }

    /**
     * {@link ITextColorStyleable}
     */

    @Override
    public int getTextColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textColor;
    }

    @Override
    public int getTextPressedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textPressedColor;
    }

    @Override
    public int getTextCheckedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textCheckedColor;
    }

    @Override
    public int getTextDisabledColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textDisabledColor;
    }

    @Override
    public int getTextFocusedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textFocusedColor;
    }

    @Override
    public int getTextSelectedColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textSelectedColor;
    }

    @Override
    public int getTextStartColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textStartColor;
    }

    @Override
    public int getTextCenterColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textCenterColor;
    }

    @Override
    public int getTextEndColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textEndColor;
    }

    @Override
    public int getTextGradientOrientationStyleable() {
        return R.styleable.ShapeRadioButton_shape_textGradientOrientation;
    }
    /**
     * {@link ICompoundButtonStyleable}
     */

    @Override
    public int getButtonDrawableStyleable() {
        return R.styleable.ShapeRadioButton_shape_buttonDrawable;
    }

    @Override
    public int getButtonPressedDrawableStyleable() {
        return R.styleable.ShapeRadioButton_shape_buttonPressedDrawable;
    }

    @Override
    public int getButtonCheckedDrawableStyleable() {
        return R.styleable.ShapeRadioButton_shape_buttonCheckedDrawable;
    }

    @Override
    public int getButtonDisabledDrawableStyleable() {
        return R.styleable.ShapeRadioButton_shape_buttonDisabledDrawable;
    }

    @Override
    public int getButtonFocusedDrawableStyleable() {
        return R.styleable.ShapeRadioButton_shape_buttonFocusedDrawable;
    }

    @Override
    public int getButtonSelectedDrawableStyleable() {
        return R.styleable.ShapeRadioButton_shape_buttonSelectedDrawable;
    }

    @Override
    public int getTextStrokeColorStyleable() {
        return R.styleable.ShapeRadioButton_shape_textStrokeColor;
    }

    @Override
    public int getTextStrokeSizeStyleable() {
        return R.styleable.ShapeRadioButton_shape_textStrokeSize;
    }
}
